==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/outputs/InMageRcmPolicyDetailsResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * InMageRcm specific policy details.
 * @property appConsistentFrequencyInMinutes The app consistent snapshot frequency in minutes.
 * @property crashConsistentFrequencyInMinutes The crash consistent snapshot frequency in minutes.
 * @property enableMultiVmSync A value indicating whether multi-VM sync has to be enabled.
 * @property instanceType Gets the class type. Overridden in derived classes.
 * Expected value is 'InMageRcm'.
 * @property recoveryPointHistoryInMinutes The duration in minutes until which the recovery points need to be stored.
 */
public data class InMageRcmPolicyDetailsResponse(
    public val appConsistentFrequencyInMinutes: Int? = null,
    public val crashConsistentFrequencyInMinutes: Int? = null,
    public val enableMultiVmSync: String? = null,
    public val instanceType: String,
    public val recoveryPointHistoryInMinutes: Int? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.recoveryservices.outputs.InMageRcmPolicyDetailsResponse):
            InMageRcmPolicyDetailsResponse = InMageRcmPolicyDetailsResponse(
            appConsistentFrequencyInMinutes = javaType.appConsistentFrequencyInMinutes().map({ args0 ->
                args0
            }).orElse(null),
            crashConsistentFrequencyInMinutes = javaType.crashConsistentFrequencyInMinutes().map({ args0 ->
                args0
            }).orElse(null),
            enableMultiVmSync = javaType.enableMultiVmSync().map({ args0 -> args0 }).orElse(null),
            instanceType = javaType.instanceType(),
            recoveryPointHistoryInMinutes = javaType.recoveryPointHistoryInMinutes().map({ args0 ->
                args0
            }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/outputs/InMageRcmPolicyDetailsResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * InMageRcm specific policy details.
 * @property appConsistentFrequencyInMinutes The app consistent snapshot frequency in minutes.
 * @property crashConsistentFrequencyInMinutes The crash consistent snapshot frequency in minutes.
 * @property enableMultiVmSync A value indicating whether multi-VM sync has to be enabled.
 * @property instanceType Gets the class type. Overridden in derived classes.
 * Expected value is 'InMageRcm'.
 * @property recoveryPointHistoryInMinutes The duration in minutes until which the recovery points need to be stored.
 */
public data class InMageRcmPolicyDetailsResponse(
    public val appConsistentFrequencyInMinutes: Int? = null,
    public val crashConsistentFrequencyInMinutes: Int? = null,
    public val enableMultiVmSync: String? = null,
    public val instanceType: String,
    public val recoveryPointHistoryInMinutes: Int? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.recoveryservices.outputs.InMageRcmPolicyDetailsResponse): InMageRcmPolicyDetailsResponse = InMageRcmPolicyDetailsResponse(
            appConsistentFrequencyInMinutes = javaType.appConsistentFrequencyInMinutes().map({ args0 ->
                args0
            }).orElse(null),
            crashConsistentFrequencyInMinutes = javaType.crashConsistentFrequencyInMinutes().map({ args0 ->
                args0
            }).orElse(null),
            enableMultiVmSync = javaType.enableMultiVmSync().map({ args0 -> args0 }).orElse(null),
            instanceType = javaType.instanceType(),
            recoveryPointHistoryInMinutes = javaType.recoveryPointHistoryInMinutes().map({ args0 ->
                args0
            }).orElse(null),
        )
    }
}
